
// globals
var g_paneCurrent		= 0;
var g_vidIsRunning		= false;
var g_playlistIsVisible	= false;
var g_equalizerIsVisible	= false;
var g_visViewIsVisible	= true;

// constants
var PANE_VIS			= 0;
var PANE_VID			= 1;
var VIDEO_WIDTH			= 255;	// pixels
var VIDEO_HEIGHT		= 145;	// pixels
var PANEL_VELOCITY		= 0;  // milliseconds
var EQ_PANEL_TRAVEL_Y	= 300;	// pixels

var THEME_SAVE_VAR_EQ		= "EqualizerPanel";
var THEME_SAVE_VAR_PLAYLIST	= "PlaylistPanel";
var THEME_SAVE_VAR_WIDTH	= "PlayerWidth";
var THEME_SAVE_VAR_HEIGHT	= "PlayerHeight";

function OnLoad() {

    ipl.setColumnResizeMode( 0, "Stretches" );
    ipl.setColumnResizeMode( 1, "AutoSizeData" );

	player.settings.autoStart = true;
	
	/* load the preset popups */
	for (i = 0; i < eq.presetCount; i++) {
		popupPreset.appendItem(eq.presetTitle(i));
	}

	/* set pane environment */
   	SetPane(PANE_VIS);
	g_vidIsRunning = player.openState == osMediaOpen && player.currentMedia.ImageSourceWidth > 0;
	g_vidIsRunning ? StartVideo() : EndVideo();

	/* set view to previous saved state */
	// assign height and width registry values to temp vars
	// as they will not exist the first time the skin is applied.
	var tWidth = theme.loadPreference(THEME_SAVE_VAR_WIDTH),
		tHeight = theme.loadPreference(THEME_SAVE_VAR_HEIGHT);
	
	// assign the height and width values to the view
	vPlayer.width	= (tWidth && (tWidth > vPlayer.minWidth))
						? tWidth
						: vPlayer.minWidth;
	vPlayer.height	= (tHeight && (tHeight > vPlayer.minHeight))
						? tHeight
						: vPlayer.minHeight;
						
    if (theme.loadPreference(THEME_SAVE_VAR_EQ) == "True")
		ToggleEqualizer();
    if (theme.loadPreference(THEME_SAVE_VAR_PLAYLIST) == "True")
        TogglePlaylist();


    OnOpenStateChangeTransport(player.openState);
    OnPlayStateChangeTransport(player.playState);
    OnStatusChangeTransport(player.status);
    
   	OnPlayStateChange();
	OnOpenStateChange();
 	
}

function OnClose() {
	// save view state
    theme.savePreference(THEME_SAVE_VAR_PLAYLIST,	g_playlistIsVisible);
	theme.savePreference(THEME_SAVE_VAR_WIDTH,		vPlayer.width);
	theme.savePreference(THEME_SAVE_VAR_HEIGHT,		vPlayer.height);
}



function Init(){
	onOpenStateChange();
	onPlayStateChange();
    vidIsRunning = (player.openState == osMediaOpen) && (player.currentMedia.ImageSourceWidth > 0);
}



function updateVolToolTip(id){
	vol = "";
	vol += player.settings.volume;
	eval(id + ".toolTip = vol" );

}


function updateMetadata(){

	if(player.openState!=13) return;

	metadata.value = player.status;

	authorppl = player.currentmedia.getiteminfo("#author");

	if (authorppl == "") {
		authorppl = player.currentmedia.getiteminfo("author");
	}

	if (authorppl != "") {
		authorppl += " - ";
	}

	if (metadata.value != "") {
		metadata.value += " - ";
	}

	metadata.value += authorppl;
	metadata.value += player.currentmedia.name;
	metadata.scrolling = (metadata.textWidth>metadata.width);

}


function SetPane(pane) {

	switch (pane) {
		case PANE_VIS:
			vid.visible		= false;
			vis.visible		= true;

			vPlayer.width	= vPlayer.minWidth;
			vPlayer.height	= vPlayer.minHeight;

			break;
		case PANE_VID:
			vid.visible		= true;
			vis.visible		= false;
			break;
	}
	
	g_paneCurrent = pane;
}

function StartVideo() {
	g_vidIsRunning = true;
	SetPane(PANE_VID);

	var vidWidth	= player.currentMedia.imageSourceWidth;
	var vidHeight	= player.currentMedia.imageSourceHeight;
	
	if (vidWidth > VIDEO_WIDTH && vidHeight > VIDEO_HEIGHT) {
		vPlayer.width	= vPlayer.minWidth + (vidWidth - VIDEO_WIDTH);
		vPlayer.height	= vPlayer.minHeight + (vidHeight - VIDEO_HEIGHT);
	}
		
}


function EndVideo() {

	g_vidIsRunning = false;

	vPlayer.width	= vPlayer.minWidth;
	vPlayer.height	= vPlayer.minHeight;
	
	if (g_paneCurrent == PANE_VID) {
		SetPane(PANE_VIS);
	}
}

function TogglePlaylist() {
	
	if (!g_playlistIsVisible) {
		ipl.moveTo(0, 0, PANEL_VELOCITY);
	} else {
		ipl.moveTo(0, 520, PANEL_VELOCITY);
	}
	
	bPlaylist.down = g_playlistIsVisible = !g_playlistIsVisible;
}

function ToggleEqualizer() {

	if (!g_equalizerIsVisible) {
		ddpl.visible = true;
		svPanel.moveTo(0, 0, EQ_PANEL_TRAVEL_Y);
	} else {
		ddpl.visible = false;
		svPanel.moveTo(165, 0, EQ_PANEL_TRAVEL_Y);
	}

	bEq.down = g_equalizerIsVisible = !g_equalizerIsVisible;
}

function OpenMedia() {

	newFile = theme.openDialog('FILE_OPEN', 'FILES_ALLMEDIA');
	if (newFile) {
		player.URL = newFile;
		player.controls.play();
	}
}

function OnOpenStateChange() {

	if (player.openState == osMediaOpen) {
		g_vidIsRunning = player.currentMedia.ImageSourceWidth > 0;
		g_vidIsRunning ? StartVideo() : EndVideo();
	}			
}

function OnPlayStateChange() {

    switch (player.playState) {
        case psStopped:
            vis.visible = false;  
            break;
        case psPaused:
            vis.visible = false;  
            break;
        case psPlaying:
        default:
            vis.visible = !g_vidIsRunning;
   }

}

function OnModeChange(NewMode, NewValue) {
	if (NewMode == 'shuffle')
		bShuffle.down = NewValue;
}
